==> kblogger_0.6.2.orig.tar.gz: kblogger-0.6.2/src/kbloggerlinkdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBLOGGERLINKDIALOG_H
#define KBLOGGERLINKDIALOG_H

#include "kbloggerlinkdialogblank.h"

class KBloggerLinkDialog : public KBloggerLinkDialogBlank
{
Q_OBJECT
public:
    KBloggerLinkDialog(QWidget *parent = 0, const char *name = 0);
signals:
    void addLink( QString, QString );
public slots:
    virtual void addLinkSlot();
};

#endif

==> kblogger_0.6.5.orig.tar.gz: kblogger-0.6.5/src/kbloggerlinkdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBLOGGERLINKDIALOG_H
#define KBLOGGERLINKDIALOG_H

#include <klineedit.h>
#include "kbloggerlinkdialogblank.h"

class KBloggerLinkDialog : public KBloggerLinkDialogBlank
{
Q_OBJECT
public:
    KBloggerLinkDialog(QWidget *parent = 0, const char *name = 0);
    void setName(const QString &linkName); //Link Name
signals:
    void addLink( QString, QString );
public slots:
    virtual void addLinkSlot();
private:
    QString sanitize(const QString& dirtyString); //Remove Tags if present in the text.
};

#endif
